@@ -2,11 +2,11 @@
 
 SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null && pwd )"
 
-[[ ! "${OPENCV_QUIET}" ]] && ( echo "Setting vars for OpenCV 4.0.0" )
+[[ ! "${OPENCV_QUIET}" ]] && ( echo "Setting vars for OpenCV 4.1.0" )
 export LD_LIBRARY_PATH="$SCRIPT_DIR/../lib:$LD_LIBRARY_PATH"
 
 if [[ ! "$OPENCV_SKIP_PYTHON" ]]; then
-  PYTHONPATH_OPENCV="$SCRIPT_DIR/../python"
+  PYTHONPATH_OPENCV="$SCRIPT_DIR/../usr/lib/python3.7/site-packages"
   [[ ! "${OPENCV_QUIET}" ]] && ( echo "Append PYTHONPATH: ${PYTHONPATH_OPENCV}" )
   export PYTHONPATH="${PYTHONPATH_OPENCV}:$PYTHONPATH"
 fi
